all.Amianhinfusionsm<-function(){
     cat("\n")                                                                       
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous iv infusion input data information--     \n")
     note_for_Thesm_conc_input()
     cat("-----------------------------------------------------------------------\n")                                                      
     cat("\n")
     note_for_close_window()
     AmianhinfusionSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","Ro (mg/hr)"),
                                      value=c(0,36,176,0,0,400,24,30))
     AmianhinfusionSMMpar<-edit(AmianhinfusionSMMpar)
##     AmianhinfusionSMMpar<-ycheck(AmianhinfusionSMMpar)
     cat("\n")
     cat("\n Input data are as follows:\n")
     cat(" --------------------------  \n")
     show(AmianhinfusionSMMpar);cat("\n\n")
     cat("------------------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous iv infusion input data information--      \n")
     note_for_Theinfusionsm_input()
     cat("------------------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmianhinfusionSMpar<-data.frame(ts=c(6, 12),conc=c(8.1,11.2))                                                                                                                            
     AmianhinfusionSMpar<-edit(AmianhinfusionSMpar)
     show(AmianhinfusionSMpar);cat("\n\n")
     ### AmianhinfusionSMpar<-mscheck(AmianhinfusionSMpar)                                         
     cat("\n")
     Amianhinfusion.sm(length(AmianhinfusionSMpar$ts),AmianhinfusionSMpar$conc,AmianhinfusionSMpar$ts,AmianhinfusionSMMpar[3,2],AmianhinfusionSMMpar[2,2],AmianhinfusionSMMpar[5,2],AmianhinfusionSMMpar[1,2],AmianhinfusionSMMpar[4,2],AmianhinfusionSMMpar[6,2],AmianhinfusionSMMpar[8,2],AmianhinfusionSMMpar[7,2])
     note_for_convergence_plots()
     X <- read.table("params.csv",header=FALSE)
     cl <- X[1,2]
     v  <- X[2,2]
     ### convergence_plots_sep()
     cat("------------------------------------------------------------------------\n")
     cat("   --Aminophylline anhydrous iv infusion output data information--      \n")
     note_for_Theinfusionsm_output()
     cat("------------------------------------------------------------------------\n")
     ### show(samplesStats("*"))
     ### show obs. and calc. conc. here  -YJ
     ### Theinfusioncpr<-function(S,DL,R,T,tinf)
     cat("\n\n")
     for(i in 1:length(AmianhinfusionSMpar$ts)){
         Cx<-Theinfusioncpr(0.85,AmianhinfusionSMMpar[6,2],AmianhinfusionSMMpar[8,2],AmianhinfusionSMpar$ts[i],AmianhinfusionSMMpar[7,2]) 
         coutput<-data.frame(conc=c("obs. conc.","calc. conc."), values=c(AmianhinfusionSMpar$conc[i],Cx))
         cat("--- Theophylline plasma conc. (mg/L) at Time =",AmianhinfusionSMpar$ts[i],"---\n")
         show(coutput);cat("\n")
     }
     C<-0.85*AmianhinfusionSMMpar[8,2]/(cl)
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(C)
     colnames(coutput)<-list("Css_pr (mg/L)")
     show(coutput)     
     cat("\n")   
     Amianhinfusion.more()                                  
}